@@ -6,6 +6,12 @@
 #include <QDebug>
 #include <QSettings>
 #include <QFileDialog>
+#include <QInputDialog>
+#include <QMessageBox>
+
+
+
+
 
 
 namespace Ui {
@@ -28,9 +34,14 @@ private:
 
 private slots:
     void on_pushButton_clicked();
-    void on_pushButton_4_clicked();
-    void on_pushButton_2_clicked();
-    void on_pushButton_3_clicked();
+    void on_counterFourButton_clicked();
+    void on_counterThreeButton_clicked();
+    void on_counterTwoButton_clicked();
+    void on_counterOneButton_clicked();
+    void on_buttonPlusAll_clicked();
+    void on_buttonNew_clicked();
+    void on_buttonSave_clicked();
+    void on_buttonLoad_clicked();
     void writeSettings();
     void readSettings();
 };
